/* 
 * FreeSWITCH Modular Media Switching Software Library / Soft-Switch Application
 * Copyright (C) 2005/2006, Anthony Minessale II <anthmct@yahoo.com>
 *
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is FreeSWITCH Modular Media Switching Software Library / Soft-Switch Application
 *
 * The Initial Developer of the Original Code is
 * Anthony Minessale II <anthmct@yahoo.com>
 * Portions created by the Initial Developer are Copyright (C)
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 * 
 * Anthony Minessale II <anthmct@yahoo.com>
 * Neal Horman <neal at wanlink dot com>
 *
 *
 * mod_menutest.c -- Framework Demo Module
 *
 */
#include <switch.h>

static const char modname[] = "mod_menutest";

struct myobj {
	char a[120];
	int x;
};


switch_ivr_menu_t *main_menu, *sub_menu;

static switch_ivr_action_t demo_callback(struct switch_ivr_menu *menu, char *buf, size_t len, void *obj) 
{
	struct myobj *myo = obj; /* vanilla obj to pass arounf for saving state. */
	strncpy(buf, "confcall/dk-kicked", len);
	return IVR_ACTION_PLAYSOUND;
}

static void menutest_function(switch_core_session_t *session, char *data)
{
	int res=0;
	struct localuser *u;

	struct myobj myo;


	strncpy(myo.a, "hi", sizeof(myo.a));
	myo.x = 100;

	if (!data) {
		switch_log(LOG_WARNING, "menutest requires an argument\n");
		return -1;
	}
	LOCAL_USER_ADD(u);
	
	/* myo will be passed around to the callbacks if any are binded */
	switch_ivr_menu_execute(session, main_menu, NULL, &myo);
	
	LOCAL_USER_REMOVE(u);
	return res;
}

static const switch_application_interface_t menutest_application_interface = {
	/*.interface_name */ "menutest",
	/*.application_function */ menutest_function,
	NULL, NULL, NULL,
	/*.next*/ NULL
};

static switch_loadable_module_interface_t menutest_module_interface = {
	/*.module_name */ modname,
	/*.endpoint_interface */ NULL,
	/*.timer_interface */ NULL,
	/*.dialplan_interface */ NULL,
	/*.codec_interface */ NULL,
	/*.application_interface */ &menutest_application_interface,
	/*.api_interface */ NULL,
	/*.file_interface */ NULL,
	/*.speech_interface */ NULL,
	/*.directory_interface */ NULL
};

SWITCH_MOD_DECLARE(switch_status_t) switch_module_load(const switch_loadable_module_interface_t **module_interface, char *filename)
{
	/* connect my internal structure to the blank pointer passed to me */
	*module_interface = &menutest_module_interface;

	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_NOTICE, "Hello World!\n");


	switch_ivr_menu_init(&main_menu, NULL, "main_menu", "/tmp/main.wav", "/tmp/mainshort.wav", "/tmp/bad.wav", 10000, 10, 1, 0);

	switch_ivr_menu_bind_function(main_menu, demo_callback ,"1");
	switch_ivr_menu_bind_action(main_menu, IVR_ACTION_DIE, NULL, "2");
	switch_ivr_menu_bind_action(main_menu, IVR_ACTION_PLAYSOUND, "/tmp/three.wav", "3");
	switch_ivr_menu_bind_action(main_menu, IVR_ACTION_EXECMENU, "sub_menu", "4");
	switch_ivr_menu_bind_action(main_menu, IVR_ACTION_TRANSFER, "3910", "5");
	

	switch_ivr_menu_init(&sub_menu, main_menu, "sub_menu", "co", NULL, "/tmp/bad.wav", 10000, 10, 1, 0);

	switch_ivr_menu_bind_action(sub_menu, IVR_ACTION_PLAYSOUND, "/tmp/one.wav", "1");
	switch_ivr_menu_bind_action(sub_menu, IVR_ACTION_PLAYSOUND, "/tmp/two.wav", "2");
	switch_ivr_menu_bind_action(sub_menu, IVR_ACTION_BACK, NULL, "3");
	switch_ivr_menu_bind_action(sub_menu, IVR_ACTION_EXECAPP, "speak cepstral|david|Cool", "4");
	switch_ivr_menu_bind_action(sub_menu, IVR_ACTION_TOMAIN, NULL, "5");

	/* indicate that the module should continue to be loaded */
	return SWITCH_STATUS_SUCCESS;
}

/*
  Called when the system shuts down
SWITCH_MOD_DECLARE(switch_status) switch_module_shutdown(void)
{
	return SWITCH_STATUS_SUCCESS;
}
*/

/*
  If it exists, this is called in it's own thread when the module-load completes
  If it returns anything but SWITCH_STATUS_TERM it will be called again automaticly
SWITCH_MOD_DECLARE(switch_status_t) switch_module_runtime(void)
{
	while(looping)
	{
		switch_yield(1000);
	}
	return SWITCH_STATUS_TERM;
}
*/
